@@ -8,17 +8,22 @@ from typing import Any, Dict, List, Union
 def parse_plist_from_path(
     plist_path: Path,
 ) -> Union[Dict[Any, Any], List[Any]]:
-    with codecs.open(plist_path, "rb", "utf-8") as f:
+    with codecs.open(str(plist_path), "rb", "utf-8") as f:
         d = f.read()
     return parse(d)
 
 
-def save_to_plist_path(
-    obj: Union[Dict[Any, Any], List[Any]], plist_path: Path
-) -> None:
-    with codecs.open(plist_path, "wb", "utf-8") as f:
+def save_to_plist_path(obj: Union[Dict[Any, Any], List[Any]], plist_path: Path) -> None:
+    with codecs.open(str(plist_path), "wb", "utf-8") as f:
         openstep_plist.dump(
-            obj, f, unicode_escape=False, indent=0, single_line_tuples=True
+            obj,
+            f,
+            unicode_escape=False,
+            indent=0,
+            single_line_tuples=True,
+            # TODO: The released version 0.3.1 of openstep_plist doesn't have the
+            # ``escape_newlines`` argument
+            # escape_newlines=False,
         )
 
 
